@@ -68,3 +68,35 @@ class Collection(Entity):
             An object representing the collection to delete.
         """
         return self.edit(extraParams={"deleted_at": getTime()})
+
+    def getSubCollections(self):
+        """
+        Get a list of the sub-collections within the collection.
+
+        Returns
+        -------
+        List[:class:`~labstep.entities.collection.model.Collection`]
+            A list of sub-collections
+
+        """
+        import labstep.entities.collection.repository as collectionRepository
+        return collectionRepository.getCollections(self.__user__, extraParams={'outer_folder_id': self.id})
+
+    def addSubCollections(self, names):
+        """
+        Add a sub-collection sub-collections to the collection.
+
+        Parameters
+        ----------
+        name (List[str])
+            List of names of sub-collections name of the new sub-collection.
+
+        Returns
+        -------
+        :class:`~labstep.entities.collection.model.Collection`
+            An object representing the collection created.
+        """
+        import labstep.entities.collection.repository as collectionRepository
+        types = {"experiment_workflow": "experiment",
+                 "protocol_collection": "protocol"}
+        return collectionRepository.newCollections(self.__user__, names=names, type=types[self.type], extraParams={'outer_folder_id': self.id})
