@@ -11,19 +11,24 @@ def getMolecule(user, guid, extraParams={}):
     return entityRepository.getEntity(user, Molecule, guid, extraParams)
 
 
-def editMolecule(molecule, name=UNSPECIFIED, data=UNSPECIFIED, inchis=UNSPECIFIED, extraParams={}):
+def editMolecule(molecule, deleted_at=UNSPECIFIED, name=UNSPECIFIED, data=UNSPECIFIED, inchis=UNSPECIFIED, extraParams={}):
     params = {
         "name": name,
         "data": data,
         "inchis": inchis,
+        "deleted_at": deleted_at,
         **extraParams,
     }
     return entityRepository.editEntity(molecule, params)
 
 
-def newMolecule(user, extraParams={}):
+def newMolecule(user, experimentId, extraParams={}):
     params = {
         "name": 'Untitled',
+        "experiment_id": experimentId,
+        "data": "",
+        "pubchem":  None,
+        "svg": "",
         **extraParams,
     }
 
