@@ -5,6 +5,7 @@
 from labstep.service.helpers import handleKeyword
 from labstep.entities.orderRequest.model import OrderRequest
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
 def getOrderRequest(user, orderRequest_id):
@@ -14,9 +15,9 @@ def getOrderRequest(user, orderRequest_id):
 def getOrderRequests(
     user,
     count=100,
-    search_query=None,
-    tag_id=None,
-    status=None,
+    search_query=UNSPECIFIED,
+    tag_id=UNSPECIFIED,
+    status=UNSPECIFIED,
     extraParams={},
 ):
     params = {
@@ -29,19 +30,19 @@ def getOrderRequests(
     return entityRepository.getEntities(user, OrderRequest, count, params)
 
 
-def newOrderRequest(user, resource_id=None, quantity=1, extraParams={}):
+def newOrderRequest(user, resource_id=UNSPECIFIED, quantity=1, extraParams={}):
     params = {"resource_id": resource_id, "quantity": quantity, **extraParams}
     return entityRepository.newEntity(user, OrderRequest, params)
 
 
 def editOrderRequest(
     orderRequest,
-    status=None,
-    resource_id=None,
-    quantity=None,
-    price=None,
-    currency=None,
-    deleted_at=None,
+    status=UNSPECIFIED,
+    resource_id=UNSPECIFIED,
+    quantity=UNSPECIFIED,
+    price=UNSPECIFIED,
+    currency=UNSPECIFIED,
+    deleted_at=UNSPECIFIED,
     extraParams={},
 ):
     params = {
