@@ -71,12 +71,12 @@ def exportProtocol(protocol, root_path):
     for note in notes:
         note.export(notesDir)
 
-    # save materials
-    materialsDir = expDir.joinpath('materials')
-    materials = protocol.getMaterials()
+    # save inventory fields
+    inventoryFieldsDir = expDir.joinpath('inventory')
+    inventoryFields = protocol.getInventoryFields()
 
-    for material in materials:
-        material.export(materialsDir)
+    for inventoryField in inventoryFields:
+        inventoryField.export(inventoryFieldsDir)
 
     # save data
     dataDir = expDir.joinpath('data')
