@@ -145,6 +145,8 @@ def exportEntity(entity, rootPath, folderName=UNSPECIFIED):
                 entity, 'name') and entity.name is not None:
             santitisedName = entity.name.replace('/', ' ').replace('\\', ' ')
             folderName = f"{entity.id} - {santitisedName}"
+            if len(folderName) > 255:
+                folderName = str(entity.id)
         else:
             folderName = str(entity.id)
 
